@@ -7,7 +7,7 @@ require Carp;
 require Scalar::Util;
 use Routes::Tiny::Pattern;
 
-our $VERSION = 0.19;
+our $VERSION = 0.20;
 
 sub new {
     my $class = shift;
@@ -30,15 +30,8 @@ sub new {
 
 sub add_route {
     my $self = shift;
-    my ($pattern, @args) = @_;
 
-    $pattern = $self->_build_pattern(
-        strict_trailing_slash => $self->{strict_trailing_slash},
-        default_method		  => $self->{default_method},
-        routes                => $self,
-        pattern               => $pattern,
-        @args
-    );
+    my $pattern = $self->_build_pattern(@_);
 
     push @{$self->{patterns}}, $pattern;
 
@@ -99,7 +92,30 @@ sub _register_pattern_name {
     }
 }
 
-sub _build_pattern { shift; return Routes::Tiny::Pattern->new(@_) }
+sub _build_pattern {
+    my $self = shift;
+
+    if (@_ % 2) {
+        unshift(@_, 'pattern');
+    } else {
+        my $method  = shift;
+        my $pattern = shift;
+
+        if ($method =~ /^(GET|HEAD|POST|PUT|DELETE|TRACE|OPTIONS|CONNECT|PATCH)$/i) {
+            unshift(@_, pattern => $pattern);
+            unshift(@_, method  => $method);
+        } else {
+            Carp::croak("Unknown pattern http method '$_[0]'");
+        }
+    }
+
+    return Routes::Tiny::Pattern->new(
+        strict_trailing_slash => $self->{strict_trailing_slash},
+        default_method        => $self->{default_method},
+        routes                => $self,
+        @_
+    )
+}
 
 1;
 __END__
@@ -137,6 +153,7 @@ Routes::Tiny - Routes
     my $captures_hashref = $match->captures;
 
     # Matching with method
+    $routes->add_route('/hello/world', method => 'GET');
     my $match = $routes->match('/hello/world', method => 'GET');
 
     # Subroutes
@@ -215,14 +232,20 @@ It is possible to specify a globbing placeholder.
 
 It is possible to pass arguments to the match object AS IS.
 
-=head2 C<Path building>
+=head2 C<Matching with methods>
 
-    $routes->add_route('/articles/:id', name => 'article');
+    # Exact HTTP method definition
+    $routes->add_route('/articles', method => 'GET', defaults => {action => 'list'});
 
-    $path = $routes->build_path('article', id => 123);
-    # $path is '/articles/123'
+    # Sweeter method definition
+    # METHOD => PATTERN should go as first parameters to add_route()
+    $routes->add_route(PUT => '/articles', defaults => {action => 'create'});
 
-It is possible to reconstruct a path from route's name and parameters.
+    $match = $routes->match('/articles', method => 'GET');
+    # $m->captures is {action => 'list'}
+
+    $match = $routes->match('/articles', method => 'PUT');
+    # $m->captures is {action => 'create'}
 
 =head2 C<Subroutes>
 
@@ -250,6 +273,15 @@ Parent routes mounts names of children routes, so it's possible to buil path
     $path = $routes->build_path('comments', type => 'articles', id => 123, page => 5);
     # $path is '/articles/123/comments/5/'
 
+=head2 C<Path building>
+
+    $routes->add_route('/articles/:id', name => 'article');
+
+    $path = $routes->build_path('article', id => 123);
+    # $path is '/articles/123'
+
+It is possible to reconstruct a path from route's name and parameters.
+
 =head1 WARNINGS
 
 =head2 C<Trailing slash issue>
